# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`pupmod`](#pupmod): A class for managing Puppet configurations.  This is mainly a stub class for hooking other classes along the way with a small bit of logic to
* [`pupmod::agent::cron`](#pupmodagentcron): This class configures the scheduled run settings for a non-daemonized puppet client  Note: The parameters are present for backwards compatibi
* [`pupmod::facter::conf`](#pupmodfacterconf): A class to manage Facter configuration
* [`pupmod::master`](#pupmodmaster): Provides configuration for a puppet master.
* [`pupmod::master::base`](#pupmodmasterbase): A break out of the mostly static files used by the Puppet master.
* [`pupmod::master::generate_types`](#pupmodmastergenerate_types): Use ``systemd`` to run ``puppet generate types`` when the necessary files have been changed
* [`pupmod::master::install`](#pupmodmasterinstall): Install the puppetserver
* [`pupmod::master::reports`](#pupmodmasterreports): This class simply controls settings around client reports on the system.  Most importantly, it allows for purging the reports.
* [`pupmod::master::service`](#pupmodmasterservice): Split out the 'service' for cleaner dependency ordering
* [`pupmod::master::simp_auth`](#pupmodmastersimp_auth): Add SIMP-specific entries to PuppetServer's auth.conf  For documentation about *_allow and *_deny, see the puppetserver docs
* [`pupmod::master::sysconfig`](#pupmodmastersysconfig): This class provides the sysconfig settings for the ``puppetserver`` daemon.  to use. To use the default enter 'default'. (Does not affect PE.

### Defined types

* [`pupmod::conf`](#pupmodconf): This is a simple define to call the Puppet INIFile class for the passed parameters on the puppet.conf file.  The main purpose is to easily al
* [`pupmod::master::autosign`](#pupmodmasterautosign): Add an autosign entry to the puppet autosign file.  Ideally, autosign will not be used in your environment. However, should you happen to nee
* [`pupmod::master::fileserver_entry`](#pupmodmasterfileserver_entry): Manage entries in the /etc/puppet/fileserver.conf file.
* [`pupmod::pass_two`](#pupmodpass_two): A helper defined type for adding processing to fix some issues with

### Functions

* [`pupmod::java_max_memory`](#pupmodjava_max_memory): Provides a reasonable calculation for the reserved code cache value for JRuby for a system
* [`pupmod::max_active_instances`](#pupmodmax_active_instances): Provides a reasonable calculation for the maximum number of active instances for a system  Parameters are not to be used but are present as a
* [`pupmod::reserved_code_cache`](#pupmodreserved_code_cache): Provides a reasonable calculation for the reserved code cache value for JRuby for a system
* [`pupmod::server_distribution`](#pupmodserver_distribution): Figure out if we're running PC1 or PE puppet
* [`pupmod::server_version`](#pupmodserver_version): Authoritatively determine the puppet server version and return `0.0.0` if one could not be determined.

### Data types

* [`Pupmod::CaTTL`](#pupmodcattl): Matches valid Puppet CA TTL configuration
* [`Pupmod::LogLevel`](#pupmodloglevel): puppetserver log levels
* [`Pupmod::Master::SSLCiphersuites`](#pupmodmastersslciphersuites): Valid SSL Cipher Suites for the Puppet Master Webserver
* [`Pupmod::Master::SSLProtocols`](#pupmodmastersslprotocols): Valid SSL Protocols for the Puppet Master Webserver
* [`Pupmod::Memory`](#pupmodmemory): Matches valid puppetserver JAVA memory parameters
* [`Pupmod::ProfilingMode`](#pupmodprofilingmode): puppetserver profiling modes

## Classes

### <a name="pupmod"></a>`pupmod`

A class for managing Puppet configurations.

This is mainly a stub class for hooking other classes along the way
with a small bit of logic to flex the system toward being a Puppet
master or client.  It manages Puppet and Facter configurations.

All Puppet configuration parameters are, by default, written to the
[main] config block of the Puppet configuration file. Selective options
may be written to their respective components as necessary for deconfliction.

#### Parameters

The following parameters are available in the `pupmod` class:

* [`ca_port`](#ca_port)
* [`ca_server`](#ca_server)
* [`puppet_server`](#puppet_server)
* [`server_distribution`](#server_distribution)
* [`certname`](#certname)
* [`classfile`](#classfile)
* [`confdir`](#confdir)
* [`daemonize`](#daemonize)
* [`digest_algorithm`](#digest_algorithm)
* [`enable_puppet_master`](#enable_puppet_master)
* [`environmentpath`](#environmentpath)
* [`listen`](#listen)
* [`logdir`](#logdir)
* [`purge_logs`](#purge_logs)
* [`purge_logs_duration`](#purge_logs_duration)
* [`purge_log_dirs`](#purge_log_dirs)
* [`masterport`](#masterport)
* [`report`](#report)
* [`rundir`](#rundir)
* [`runinterval`](#runinterval)
* [`splay`](#splay)
* [`splaylimit`](#splaylimit)
* [`srv_domain`](#srv_domain)
* [`ssldir`](#ssldir)
* [`syslogfacility`](#syslogfacility)
* [`use_srv_records`](#use_srv_records)
* [`haveged`](#haveged)
* [`fips`](#fips)
* [`vardir`](#vardir)
* [`manage_facter_conf`](#manage_facter_conf)
* [`facter_conf_dir`](#facter_conf_dir)
* [`facter_options`](#facter_options)
* [`mock`](#mock)
* [`firewall`](#firewall)
* [`pe_classlist`](#pe_classlist)
* [`package_ensure`](#package_ensure)
* [`set_environment`](#set_environment)

##### <a name="ca_port"></a>`ca_port`

Data type: `Simplib::Port`

The port where the remote CA should be contacted.

Default value: `simplib::lookup('simp_options::puppet::ca_port', { 'default_value' => 8141 })`

##### <a name="ca_server"></a>`ca_server`

Data type: `Variant[Simplib::Host,Enum['$server']]`

The puppet CA from which to obtain your system certificates.

Default value: `simplib::lookup('simp_options::puppet::ca', { 'default_value' => '$server' })`

##### <a name="puppet_server"></a>`puppet_server`

Data type: `Variant[Simplib::Host, Array[Simplib::Host]]`

One or more puppet servers from which to retrieve your configuration.

Default value: `simplib::lookup('simp_options::puppet::server', { 'default_value' => "puppet.${facts['domain']}" })`

##### <a name="server_distribution"></a>`server_distribution`

Data type: `Simplib::ServerDistribution`

The server distribution used. This changes the configuration based on whether
we are using PC1 or PE

Default value: `pupmod::server_distribution(false)`

##### <a name="certname"></a>`certname`

Data type: `Simplib::Host`

The puppet certificate CN name of the system.

* For authenticated remote requests, this defaults to `$trusted['certname']
* For all other requests (e.g., bolt), the default is `$facts['clientcert']`

For additional details, see:

* http://docs.puppetlabs.com/references/latest/configuration.html
* https://puppet.com/docs/puppet/latest/lang_facts_builtin_variables.html

Default value: `(`

##### <a name="classfile"></a>`classfile`

Data type: `String[0]`

The path to the puppet class file.

See http://docs.puppetlabs.com/references/latest/configuration.html for
additional details.

Default value: `'$vardir/classes.txt'`

##### <a name="confdir"></a>`confdir`

Data type: `Stdlib::AbsolutePath`

The path to the puppet configuration directory.

See http://docs.puppetlabs.com/references/latest/configuration.html for
additional details.

##### <a name="daemonize"></a>`daemonize`

Data type: `Boolean`

Whether or not to daemonize the Puppet agent.

SIMP systems do not, by default, daemonize their agents so that the
consumed resources can be freed for other uses and so that the cron
job can maintain a safe system state over time.

Default value: ``false``

##### <a name="digest_algorithm"></a>`digest_algorithm`

Data type: `Enum['md5','sha256']`

The hash Digest to use for file operations on the system.

Default value: `'sha256'`

##### <a name="enable_puppet_master"></a>`enable_puppet_master`

Data type: `Boolean`

Whether or not to make the system a puppetmaster.

Default value: ``false``

##### <a name="environmentpath"></a>`environmentpath`

Data type: `Stdlib::AbsolutePath`

The path to the directory holding the puppet environments.

##### <a name="listen"></a>`listen`

Data type: `Boolean`

Whether or not to listen for incoming connections to the puppet
agent.

Given the ability to run puppet remotely via SSH, MCollective, or
many other means, we will not open this by default. If you decide to
enable it, don't forget to add an associated IPTables rule.

Default value: ``false``

##### <a name="logdir"></a>`logdir`

Data type: `Stdlib::AbsolutePath`

The path to the puppet log directory.

See http://docs.puppetlabs.com/references/latest/configuration.html for
additional details.

##### <a name="purge_logs"></a>`purge_logs`

Data type: `Boolean`

Purge old logs from the system.

Default value: ``true``

##### <a name="purge_logs_duration"></a>`purge_logs_duration`

Data type: `Pattern['\d+(h|m|w)']`

The timeframe after which logs will be purged.

* Uses systemd tmpfiles age notation

Default value: `'4w'`

##### <a name="purge_log_dirs"></a>`purge_log_dirs`

Data type: `Array[Stdlib::AbsolutePath]`

The directories under `$logdir` to be purged.

Default value: `['/puppet*']`

##### <a name="masterport"></a>`masterport`

Data type: `Simplib::Port`

The port where the Puppet Master should be contacted.

Default value: `8140`

##### <a name="report"></a>`report`

Data type: `Boolean`

Whether or not to send reports to the report server. This is
disabled by default to allow users to reduce network load unless
reports are required.

Default value: ``false``

##### <a name="rundir"></a>`rundir`

Data type: `Stdlib::AbsolutePath`

The path to the puppet run status directory.

See http://docs.puppetlabs.com/references/latest/configuration.html for
additional details.

##### <a name="runinterval"></a>`runinterval`

Data type: `Integer[0]`

The number of seconds between puppet runs.
Has no effect on the client cron job.

Default value: `1800`

##### <a name="splay"></a>`splay`

Data type: `Boolean`

Whether or not to splay the puppet runs.

This is done by default to add some randomization to client system
runs on large systems.

Default value: ``false``

##### <a name="splaylimit"></a>`splaylimit`

Data type: `Optional[Integer[1]]`



Default value: ``undef``

##### <a name="srv_domain"></a>`srv_domain`

Data type: `Simplib::Host`

The domain to search when using SRV records.

Default value: `$facts['domain']`

##### <a name="ssldir"></a>`ssldir`

Data type: `Stdlib::AbsolutePath`

The path to the puppet ssl directory.

See http://docs.puppetlabs.com/references/latest/configuration.html for
additional details.

##### <a name="syslogfacility"></a>`syslogfacility`

Data type: `Simplib::Syslog::Facility`

The Syslog facility to use when outputting messages from puppet.

Default value: `'local6'`

##### <a name="use_srv_records"></a>`use_srv_records`

Data type: `Boolean`

Whether the server will search for SRV records in DNS for the current domain.

Default value: ``false``

##### <a name="haveged"></a>`haveged`

Data type: `Boolean`

If true, include haveged to assist with entropy generation.

Default value: `simplib::lookup('simp_options::haveged', { 'default_value' => false })`

##### <a name="fips"></a>`fips`

Data type: `Boolean`

If true, enable fips mode

Default value: `simplib::lookup('simp_options::fips', { 'default_value' => false })`

##### <a name="vardir"></a>`vardir`

Data type: `Stdlib::AbsolutePath`

The directory where puppet will store all of its 'variable' data.

##### <a name="manage_facter_conf"></a>`manage_facter_conf`

Data type: `Boolean`

Whether to manage the Facter configuration file.

Default value: ``false``

##### <a name="facter_conf_dir"></a>`facter_conf_dir`

Data type: `Stdlib::Absolutepath`

Directory containing the Facter configuration file.

Default value: `'/etc/puppetlabs/facter'`

##### <a name="facter_options"></a>`facter_options`

Data type: `Hash`

Hash of Facter configuration options.
- Only applies when `manage_facter_conf` is `true`.
- Each primary key is a section in the Facter configuration file
  (e.g., 'facts', 'global', 'cli')
- When the configuration for a section is empty, that section will
  be removed entirely from the Facter configuration file.
- See https://puppet.com/docs/facter/latest/configuring_facter.html
  for details on how to configure Facter.

##### <a name="mock"></a>`mock`

Data type: `Boolean`

If true, disable all code.

Default value: ``false``

##### <a name="firewall"></a>`firewall`

Data type: `Boolean`

Whether or not firewall rules should be created

Default value: `simplib::lookup('simp_options::firewall', { 'default_value' => false })`

##### <a name="pe_classlist"></a>`pe_classlist`

Data type: `Hash`

Hash of pe classes and assorted metadata.

Default value: `{}`

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String[1]`

String used to specify 'latest', 'installed', or a specific version of the puppet-agent package

Default value: `simplib::lookup('simp_options::package_ensure' , { 'default_value' => 'installed'})`

##### <a name="set_environment"></a>`set_environment`

Data type: `Variant[Boolean, Enum['no_clean']]`

Set the environment on the system to the currently running environment

* This will automatically purge the `environment` setting from the `main`
  section of the configuration to prevent issues from arising when running
  various puppet tools. To prevent this from happening, you may set this to
  `no_clean` and the entry will be preserved if present.

Default value: ``false``

### <a name="pupmodagentcron"></a>`pupmod::agent::cron`

This class configures the scheduled run settings for a non-daemonized puppet client

Note: The parameters are present for backwards compatibility, at some point,
this class will be renamed to reflect that it is now a systemd timer.

#### Examples

##### Configure puppet agent cron to run every 20 minutes

```puppet

class { 'pupmod::agent::cron:
  interval => 20,
  minute   => 'nil'
}
```

##### Configure puppet agent cron to run once an hour using

```puppet
the default minute randomization algorithm

class { 'pupmod::agent::cron:
  runs_per_timeframe => 1
}
```

##### Configure cron to run once per day at a particular time

```puppet

class { 'pupmod::agent::cron:
  minute => '23'
  hour   => '4'
}
```

#### Parameters

The following parameters are available in the `pupmod::agent::cron` class:

* [`enable`](#enable)
* [`interval`](#interval)
* [`minute_base`](#minute_base)
* [`run_timeframe`](#run_timeframe)
* [`runs_per_timeframe`](#runs_per_timeframe)
* [`systemd_calendar`](#systemd_calendar)
* [`minute`](#minute)
* [`hour`](#hour)
* [`monthday`](#monthday)
* [`month`](#month)
* [`weekday`](#weekday)
* [`maxruntime`](#maxruntime)
* [`break_puppet_lock`](#break_puppet_lock)
* [`max_disable_time`](#max_disable_time)

##### <a name="enable"></a>`enable`

Data type: `Boolean`

Enable, or disable, the scheduled agent run

Default value: ``true``

##### <a name="interval"></a>`interval`

Data type: `Integer[0]`

The cron iteration time (in minutes) for running puppet

* When ``$minute`` is set to 'nil', this applies the standard
  ``*/$interval`` style syntax from cron for the minute field.
  See ``crontab(5)`` for additional details.

* Otherwise, this value is ignored.

Default value: `30`

##### <a name="minute_base"></a>`minute_base`

Data type: `String`

The default artifact to use to auto-generate a cron interval

* The default of ``$::ipaddress`` is used to provide a reasonable guess at
  spreading the puppet runs across all of your systems. However, you can
  set this to *anything* that you like.

* Use ``$::ipaddress_eth0`` to generate the entry from the eth0 IP Address

* Use ``$::uniqueid`` to generate the entry from the system UUID

* WARNING: If this is the *same* resolved value on all of your systems then
  your systems will have the *same* run interval.

* Not used if using ``$interval``

Default value: `$facts['ipaddress']`

##### <a name="run_timeframe"></a>`run_timeframe`

Data type: `Integer[0]`

The time frame within which you wish to run the puppet agent

* This directly translates to the minute field of the cron job so this
  should probably be left at 60

* Not used if using ``$interval``

Default value: `60`

##### <a name="runs_per_timeframe"></a>`runs_per_timeframe`

Data type: `Integer[0]`

The number of times, per ``$timeframe``, that you want to run the Puppet
Agent.

* Not used if using ``$interval``

Default value: `2`

##### <a name="systemd_calendar"></a>`systemd_calendar`

Data type: `Optional[String[1]]`

The exact systemd calendar string to add to the timer

* This is **not** checked for correctess

Default value: ``undef``

##### <a name="minute"></a>`minute`

Data type: `Variant[Simplib::Cron::Minute,Enum['nil','ip_mod','rand','sha256']]`

The ``minute`` value for the crontab entry

Set to ``nil`` if you want to only use ``$interval``.

Set to one of the randiomization algorithms if you want the minute
to be auto-generated from ``$minute_base``:

``ip_mod`` or its backward-compatible alias ``rand`` uses a
IP-modulus-based transformation of the numeric IP representation of
``$minute_base``, when ``$minute_base`` is an IP address.
Otherwise, it uses a crc32-based transformation of $minute_base.
This algorithm works well when the number of hosts managed by a
Puppet master exceeds 60 and the hosts have linearly-assigned IP
addresses.

``sha256`` uses a SHA256-based transformation ``$minute_base``.
This algorithm provides general randomization for cases in which
``ip_mod`` yields undesirable clustering.

Default value: `'ip_mod'`

##### <a name="hour"></a>`hour`

Data type: `Simplib::Cron::Hour`

The ``hour`` value for the crontab entry

* Not used if using ``$interval``

Default value: `'*'`

##### <a name="monthday"></a>`monthday`

Data type: `Simplib::Cron::MonthDay`

The ``monthday`` value for the crontab entry

* Not used if using ``$interval``

Default value: `'*'`

##### <a name="month"></a>`month`

Data type: `Simplib::Cron::Month`

The ``month`` value for the crontab entry

* Not used if using ``$interval``

Default value: `'*'`

##### <a name="weekday"></a>`weekday`

Data type: `Simplib::Cron::Weekday`

The ``weekday`` value for the crontab entry

* Not used if using ``$interval``

Default value: `'*'`

##### <a name="maxruntime"></a>`maxruntime`

Data type: `Integer[1]`

How long (in minutes) a puppet agent will be allowed to run before being
forcibly stopped

Default value: `240`

##### <a name="break_puppet_lock"></a>`break_puppet_lock`

Data type: `Boolean`

Forcibly enable the puppet agent if it has been disabled for
``$max_disable_time``

* This is enabled by default so that the system can remain in a
  self-healing state

Default value: ``true``

##### <a name="max_disable_time"></a>`max_disable_time`

Data type: `Optional[Integer[1]]`

How long (in minutes) a puppet agent will be allowed to remain disabled
before being forcibly enabled

* This only takes effect if ``$break_puppet_lock`` is true

* When not set, an appropriate value is computed based on
  cron frequency and ``$maxruntime``.

Default value: ``undef``

### <a name="pupmodfacterconf"></a>`pupmod::facter::conf`

A class to manage Facter configuration

#### Parameters

The following parameters are available in the `pupmod::facter::conf` class:

* [`facter_conf_dir`](#facter_conf_dir)
* [`facter_options`](#facter_options)

##### <a name="facter_conf_dir"></a>`facter_conf_dir`

Data type: `Stdlib::Absolutepath`

Facter configuration directory

Default value: `$::pupmod::facter_conf_dir`

##### <a name="facter_options"></a>`facter_options`

Data type: `Hash`

Facter configuration Hash

Default value: `$::pupmod::facter_options`

### <a name="pupmodmaster"></a>`pupmod::master`

Provides configuration for a puppet master.

* **See also**
  * https://puppet.com/docs/puppetserver/5.2/config_file_puppetserver.html

#### Parameters

The following parameters are available in the `pupmod::master` class:

* [`bind_address`](#bind_address)
* [`ca_allow_auth_extensions`](#ca_allow_auth_extensions)
* [`ca_allow_alt_names`](#ca_allow_alt_names)
* [`ca_bind_address`](#ca_bind_address)
* [`auditd`](#auditd)
* [`ca_port`](#ca_port)
* [`trusted_nets`](#trusted_nets)
* [`server_distribution`](#server_distribution)
* [`server_type`](#server_type)
* [`ca_ttl`](#ca_ttl)
* [`daemonize`](#daemonize)
* [`enable_ca`](#enable_ca)
* [`enable_master`](#enable_master)
* [`environmentpath`](#environmentpath)
* [`freeze_main`](#freeze_main)
* [`masterport`](#masterport)
* [`puppet_confdir`](#puppet_confdir)
* [`confdir`](#confdir)
* [`codedir`](#codedir)
* [`vardir`](#vardir)
* [`rundir`](#rundir)
* [`logdir`](#logdir)
* [`ssldir`](#ssldir)
* [`use_legacy_auth_conf`](#use_legacy_auth_conf)
* [`max_queued_requests`](#max_queued_requests)
* [`max_retry_delay`](#max_retry_delay)
* [`firewall`](#firewall)
* [`ca_status_whitelist`](#ca_status_whitelist)
* [`ruby_load_path`](#ruby_load_path)
* [`max_active_instances`](#max_active_instances)
* [`max_requests_per_instance`](#max_requests_per_instance)
* [`borrow_timeout`](#borrow_timeout)
* [`environment_class_cache_enabled`](#environment_class_cache_enabled)
* [`compat_version`](#compat_version)
* [`compile_mode`](#compile_mode)
* [`ssl_protocols`](#ssl_protocols)
* [`ssl_cipher_suites`](#ssl_cipher_suites)
* [`enable_profiler`](#enable_profiler)
* [`profiling_mode`](#profiling_mode)
* [`profiler_output_file`](#profiler_output_file)
* [`admin_api_whitelist`](#admin_api_whitelist)
* [`admin_api_mountpoint`](#admin_api_mountpoint)
* [`log_to_file`](#log_to_file)
* [`strict_hostname_checking`](#strict_hostname_checking)
* [`cve_2020_7942_warning`](#cve_2020_7942_warning)
* [`syslog`](#syslog)
* [`syslog_facility`](#syslog_facility)
* [`syslog_message_format`](#syslog_message_format)
* [`log_level`](#log_level)
* [`autosign_hosts`](#autosign_hosts)
* [`package_ensure`](#package_ensure)
* [`enable_analytics`](#enable_analytics)
* [`server_webserver_options`](#server_webserver_options)
* [`ca_webserver_options`](#ca_webserver_options)
* [`extra_webserver_sections`](#extra_webserver_sections)
* [`mock`](#mock)

##### <a name="bind_address"></a>`bind_address`

Data type: `Simplib::IP`

The IP address to which the Puppet Master process should bind

Default value: `'0.0.0.0'`

##### <a name="ca_allow_auth_extensions"></a>`ca_allow_auth_extensions`

Data type: `Boolean`

If true, allows the CA to sign certificates with authorization extensions.

Default value: ``false``

##### <a name="ca_allow_alt_names"></a>`ca_allow_alt_names`

Data type: `Boolean`

If true, allows the CA to sign certificates with subject alternative names.

Default value: ``false``

##### <a name="ca_bind_address"></a>`ca_bind_address`

Data type: `Simplib::IP`

The IP address to which the Puppet CA process should bind

Default value: `'0.0.0.0'`

##### <a name="auditd"></a>`auditd`

Data type: `Boolean`

If true, adds an audit record to watch sensitive Puppet directories for
changes by any user that is not the puppet user.

Default value: `simplib::lookup('simp_options::auditd', { 'default_value' => false })`

##### <a name="ca_port"></a>`ca_port`

Data type: `Simplib::Port`

The port upon which the CA should listen. This has been modified from the
default setting of 8140 so that it does not interfere with the certificate
verification of various clients.

Default value: `simplib::lookup('simp_options::puppet::ca_port', { 'default_value' => 8141 })`

##### <a name="trusted_nets"></a>`trusted_nets`

Data type: `Simplib::NetList`

An array of networks from which to allow access to the master.

Default value: `simplib::lookup('simp_options::trusted_nets', { 'default_value' => ['127.0.0.1','::1'] })`

##### <a name="server_distribution"></a>`server_distribution`

Data type: `String`

*Deprecated*: The version of the server that is being managed.

* PC1 covers everything after Puppet 3

Default value: `pupmod::server_distribution()`

##### <a name="server_type"></a>`server_type`

Data type: `Enum['monolithic', 'primary', 'compile']`

The type of Puppet server this is. Can be 'monolithic', 'primary', or 'compile'
as defined in https://puppet.com/docs/puppetserver/latest/scaling_puppet_server.html

Default value: `'monolithic'`

##### <a name="ca_ttl"></a>`ca_ttl`

Data type: `Pupmod::CaTTL`

This is the length after which the CA certificate will no longer be valid.

Default value: `'10y'`

##### <a name="daemonize"></a>`daemonize`

Data type: `Boolean`

Whether or not to run the server as a daemon.

Default value: ``true``

##### <a name="enable_ca"></a>`enable_ca`

Data type: `Boolean`

Whether or not the system should act as a CA.

Default value: ``true``

##### <a name="enable_master"></a>`enable_master`

Data type: `Boolean`

Whether or not the system should act as a Puppet Master

Default value: ``true``

##### <a name="environmentpath"></a>`environmentpath`

Data type: `Stdlib::AbsolutePath`

The location of all directory environments.

Default value: `$pupmod::environmentpath`

##### <a name="freeze_main"></a>`freeze_main`

Data type: `Boolean`

Whether or not code is allowed outside of site.pp or a module.

Default value: ``false``

##### <a name="masterport"></a>`masterport`

Data type: `Simplib::Port`

The port upon which the Puppet master process will listen.

Default value: `8140`

##### <a name="puppet_confdir"></a>`puppet_confdir`

Data type: `Stdlib::AbsolutePath`

The Puppet server configuration directory.

Default value: `$pupmod::confdir`

##### <a name="confdir"></a>`confdir`

Data type: `Stdlib::AbsolutePath`

The Puppet client configuration directory.

##### <a name="codedir"></a>`codedir`

Data type: `Stdlib::AbsolutePath`

The directory holding the Puppet configuration codebase.

##### <a name="vardir"></a>`vardir`

Data type: `Stdlib::AbsolutePath`

The Puppet server 'var' directory

##### <a name="rundir"></a>`rundir`

Data type: `Stdlib::AbsolutePath`

The Puppet server runtime directory

##### <a name="logdir"></a>`logdir`

Data type: `Stdlib::AbsolutePath`

The log directory for the Puppet server

##### <a name="ssldir"></a>`ssldir`

Data type: `Stdlib::AbsolutePath`

The SSL configuration directory for the Puppet server

##### <a name="use_legacy_auth_conf"></a>`use_legacy_auth_conf`

Data type: `Boolean`

Enable processing of the legacy Puppetserver auth.conf.

* This is **NOT** recommended and may cause a SIMP installation to
  malfunction.

Default value: ``false``

##### <a name="max_queued_requests"></a>`max_queued_requests`

Data type: `Integer[0]`

The number of requests that may be queued against the server prior to being
rejected.

* Only functional on ``puppetserver`` >= 5.4.1

Default value: `10`

##### <a name="max_retry_delay"></a>`max_retry_delay`

Data type: `Integer[1]`

The maximum time that a client will wait prior to giving up on the server
response.

* Only functional on ``puppetserver`` >= 5.4.1

Default value: `1800`

##### <a name="firewall"></a>`firewall`

Data type: `Boolean`

If enabled, will use the SIMP iptables classes to manipulate IPTables.

Default value: `simplib::lookup('simp_options::firewall', { 'default_value' => false })`

##### <a name="ca_status_whitelist"></a>`ca_status_whitelist`

Data type: `Array[Simplib::Host]`

An array of certificate short names which will be allowed to query the CA end
point of the Puppet Server

Default value: `[pick($facts['certname'],                                                                      $facts['fqdn'])]`

##### <a name="ruby_load_path"></a>`ruby_load_path`

Data type: `Optional[Stdlib::AbsolutePath]`

The path to the system Ruby installation to use for the Puppet Server

Default value: ``undef``

##### <a name="max_active_instances"></a>`max_active_instances`

Data type: `Integer[1]`

The maximum number of active JRuby instances to be run by the Puppet Server

Default value: `pupmod::max_active_instances($server_type)`

##### <a name="max_requests_per_instance"></a>`max_requests_per_instance`

Data type: `Integer`

The number of requests a given JRuby instance will process prior to being
stopped.

Default value: `100000`

##### <a name="borrow_timeout"></a>`borrow_timeout`

Data type: `Integer[1000]`

The timeout, in milliseconds, when attempting to borrow an instance from
the JRuby pool.

Default value: `1200000`

##### <a name="environment_class_cache_enabled"></a>`environment_class_cache_enabled`

Data type: `Boolean`

Maintain a cache in conjucntion with the use of the ``environment_classes``
API.

Default value: ``true``

##### <a name="compat_version"></a>`compat_version`

Data type: `Optional[Pattern['^\d+\.\d+$']]`

Set the JRuby compat version

* Has no effect on ``puppetserver`` >= 5.0

Default value: ``undef``

##### <a name="compile_mode"></a>`compile_mode`

Data type: `Enum['off', 'jit', 'force']`

Set the JRuby ``CompileMode``.

Default value: `'off'`

##### <a name="ssl_protocols"></a>`ssl_protocols`

Data type: `Array[Pupmod::Master::SSLProtocols]`

The protocols that are allowed for communication with the Puppet Server. See
the ssl-protocols documentation for the Puppet Server for additional details.

Default value: `['TLSv1.2']`

##### <a name="ssl_cipher_suites"></a>`ssl_cipher_suites`

Data type: `Optional[Array[Pupmod::Master::SSLCipherSuites]]`

The allowed SSL Cipher Suites to be used by the Puppet Server. The allowed
list is Java version dependent and you will need to check the system Java
documentation for details.

* The default is in the module data

Default value: ``undef``

##### <a name="enable_profiler"></a>`enable_profiler`

Data type: `Boolean`

Whether or not to enable the Puppet Server profiler to allow for code metrics
gathering.

Default value: ``false``

##### <a name="profiling_mode"></a>`profiling_mode`

Data type: `Pupmod::ProfilingMode`

The JRuby profiling mode to use when profiling the server.

* Only functional on ``puppetserver`` >= 5.4.1

Default value: `'off'`

##### <a name="profiler_output_file"></a>`profiler_output_file`

Data type: `Stdlib::AbsolutePath`

The file to use when outputting server profiling information

* Only functional on ``puppetserver`` >= 5.4.1

Default value: `"${vardir}/server_jruby_profiling"`

##### <a name="admin_api_whitelist"></a>`admin_api_whitelist`

Data type: `Array[Simplib::Hostname]`

A list of X.509 certificate names that should be allowed to access the Puppet
Server's administrative API.

Default value: `[pick($facts['certname'],                                                                      $facts['fqdn'])]`

##### <a name="admin_api_mountpoint"></a>`admin_api_mountpoint`

Data type: `String`

The endpoint for the Puppet Servers adminstrative API. Changing this may
break external utilities.

Default value: `'/puppet-admin-api'`

##### <a name="log_to_file"></a>`log_to_file`

Data type: `Boolean`

If true, log to system log files at /var/log/puppetserver.

Default value: ``false``

##### <a name="strict_hostname_checking"></a>`strict_hostname_checking`

Data type: `Boolean`

Whether to only search for the complete hostname as it is in the
certificate when searching for node information in teh catalogs or to match
dot delimited segments of the cert's certname and the hostname, fqdn,
and/or domain facts.

* Do NOT set to `false` unless you have read the details of CVE-2020-7942

Default value: ``true``

##### <a name="cve_2020_7942_warning"></a>`cve_2020_7942_warning`

Data type: `Boolean`

Whether to warn about CVE-2020-7942 when the issue is detected.

Default value: ``true``

##### <a name="syslog"></a>`syslog`

Data type: `Boolean`

If true, log to the local system logger over UDP port 514.

Default value: `simplib::lookup('simp_options::syslog', { 'default_value' => false })`

##### <a name="syslog_facility"></a>`syslog_facility`

Data type: `String`

The syslog facility to which to report if using syslog.

Default value: `'LOCAL6'`

##### <a name="syslog_message_format"></a>`syslog_message_format`

Data type: `String`

The Logback compatible syslog message format. For more information, see the
Logback documentation for 'SuffixPattern'.

Default value: `'%logger[%thread]: %msg'`

##### <a name="log_level"></a>`log_level`

Data type: `Pupmod::LogLevel`

Type: One of ['TRACE','DEBUG','INFO','WARN','ERROR','OFF']
A syslog severity string limiting the messages reported. Be aware that
anything above 'WARN' will provide a massive amount of logs at each puppet
run.

Default value: `'WARN'`

##### <a name="autosign_hosts"></a>`autosign_hosts`

Data type: `Optional[Array[String[1]]]`

An array of hosts or host globs to add to the master's ``autosign.conf`` file

* WARNING: If set, will be **authoritative** and overwrite the entire file!

Default value: ``undef``

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String`

String used to specify either 'latest', 'installed', or a specific version
of the puppetserver package

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

##### <a name="enable_analytics"></a>`enable_analytics`

Data type: `Boolean`

Enable the built-in analytics, and upgrade check, on the puppetserver

Default value: ``false``

##### <a name="server_webserver_options"></a>`server_webserver_options`

Data type: `Optional[Hash[String[1],String[1]]]`

A ``Hash`` of ``String,String`` pairs that will be added as HOCON formatted
options to the ``base`` section of the server's webserver.conf
configuration.

This is completely unvalidated and is present to allow setting many of the
more escoteric options that can be found in the webserver configuration
documentation at
https://github.com/puppetlabs/trapperkeeper-webserver-jetty9/blob/master/doc/jetty-config.md

The results will be printed in the order that they are defined as `key:
value` with no additional formatting so take care to ensure that your
values are in proper HOCON format per
https://github.com/lightbend/config/blob/master/HOCON.md

Default value: ``undef``

##### <a name="ca_webserver_options"></a>`ca_webserver_options`

Data type: `Optional[Hash[String[1],String[1]]]`

A ``Hash`` of ``String,String`` pairs that will be added as HOCON formatted
options to the ``ca`` section of the server's webserver.conf configuration.

This is completely unvalidated and is present to allow setting many of the
more escoteric options that can be found in the webserver configuration
documentation at
https://github.com/puppetlabs/trapperkeeper-webserver-jetty9/blob/master/doc/jetty-config.md

The results will be printed in the order that they are defined as `key:
value` with no additional formatting so take care to ensure that your
values are in proper HOCON format per
https://github.com/lightbend/config/blob/master/HOCON.md

Default value: ``undef``

##### <a name="extra_webserver_sections"></a>`extra_webserver_sections`

Data type: `Optional[Hash[String[1],Hash[String[1],String[1]]]]`

A ``Hash`` using the following format to express the full contents of a
webserver configuration section with options as defined in
https://github.com/puppetlabs/trapperkeeper-webserver-jetty9/blob/master/doc/jetty-config.md

Section Hash Example:

```ruby
{
  'section1_name' => {
    'ssl-port' => 1234
  },
  'section2_name' => {
    'ssl-port' => 2345
  }
}
```

Result Example:

```json
webserver: {
  ...pre-existing material...
  section1_name: {
    ssl-port: 1234
  }
  section2_name: {
    ssl-port: 2345
  }
}
```

This is completely unvalidated and is present to allow setting many of the
more escoteric options that can be found in the webserver configuration
documentation at
https://github.com/puppetlabs/trapperkeeper-webserver-jetty9/blob/master/doc/jetty-config.md

The results will be printed in the order that they are defined as `key:
value` with no additional formatting so take care to ensure that your
values are in proper HOCON format per
https://github.com/lightbend/config/blob/master/HOCON.md

Default value: ``undef``

##### <a name="mock"></a>`mock`

Data type: `Boolean`

DO NOT USE. needed for rspec testing

Default value: ``false``

### <a name="pupmodmasterbase"></a>`pupmod::master::base`

A break out of the mostly static files used by the Puppet master.

### <a name="pupmodmastergenerate_types"></a>`pupmod::master::generate_types`

NOTE: ``incron`` support has been removed due to continuing issues with ``incrond``.
If you are using a system that does not support ``systemd``, you will need to
run ``simp_generate_types`` using an alternate method (such as an ``r10k``
post script).

#### Parameters

The following parameters are available in the `pupmod::master::generate_types` class:

* [`enable`](#enable)
* [`trigger_on_puppetserver_update`](#trigger_on_puppetserver_update)
* [`puppetserver_exe`](#puppetserver_exe)
* [`trigger_on_puppet_update`](#trigger_on_puppet_update)
* [`puppet_exe`](#puppet_exe)
* [`trigger_on_new_environment`](#trigger_on_new_environment)
* [`trigger_on_type_change`](#trigger_on_type_change)
* [`timeout`](#timeout)
* [`stability_timeout`](#stability_timeout)
* [`run_dir`](#run_dir)

##### <a name="enable"></a>`enable`

Data type: `Boolean`

Enable or disable automatic generation of types using ``puppet generate types``

Default value: ``true``

##### <a name="trigger_on_puppetserver_update"></a>`trigger_on_puppetserver_update`

Data type: `Boolean`

Run ``puppet generate types`` on all environments if the ``puppetserver``
application is updated

Default value: ``true``

##### <a name="puppetserver_exe"></a>`puppetserver_exe`

Data type: `Stdlib::AbsolutePath`

Fully qualified path to the ``puppetserver`` executable

Default value: `'/opt/puppetlabs/server/apps/puppetserver/bin/puppetserver'`

##### <a name="trigger_on_puppet_update"></a>`trigger_on_puppet_update`

Data type: `Boolean`

Run ``puppet generate types`` on all environments if the ``puppet``
application is updated

Default value: ``true``

##### <a name="puppet_exe"></a>`puppet_exe`

Data type: `Stdlib::AbsolutePath`

Fully qualified path to the ``puppet`` executable

Default value: `'/opt/puppetlabs/puppet/bin/puppet'`

##### <a name="trigger_on_new_environment"></a>`trigger_on_new_environment`

Data type: `Boolean`

Run ``puppet generate types`` on new environments as soon as they are
created

Default value: ``true``

##### <a name="trigger_on_type_change"></a>`trigger_on_type_change`

Data type: `Boolean`

Watch all type files for changes and generate types when types are updated

Default value: ``true``

##### <a name="timeout"></a>`timeout`

Data type: `Integer[0]`

Seconds before the simp_generate_types script will kill any other
simp_generate_types processes and continue

Default value: `300`

##### <a name="stability_timeout"></a>`stability_timeout`

Data type: `Integer[0]`

Seconds before the simp_generate_types script will exit, without
processing, due to environments continuing to be created in the environment
path while the simp_generate_types script is attempting to execute

* This comes into play when deploying large numbers of environments and
  generally should not need to be changed otherwise. If you see an error
  message relating to environments not reaching stability, then you will
  need to increase this number.

Default value: `500`

##### <a name="run_dir"></a>`run_dir`

Data type: `Stdlib::AbsolutePath`

The directory to use for saving state and metadata for the
``simp_generate_types`` process

Default value: `'/var/run/simp_generate_types'`

### <a name="pupmodmasterinstall"></a>`pupmod::master::install`

Install the puppetserver

#### Parameters

The following parameters are available in the `pupmod::master::install` class:

* [`package_name`](#package_name)
* [`package_ensure`](#package_ensure)

##### <a name="package_name"></a>`package_name`

Data type: `String[1]`



Default value: `pupmod::server_distribution()`

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String[1]`



Default value: `pick(getvar('pupmod::master::package_ensure'), 'installed')`

### <a name="pupmodmasterreports"></a>`pupmod::master::reports`

This class simply controls settings around client reports on the system.

Most importantly, it allows for purging the reports.

#### Parameters

The following parameters are available in the `pupmod::master::reports` class:

* [`vardir`](#vardir)
* [`purge`](#purge)
* [`purge_keep_days`](#purge_keep_days)
* [`purge_verbose`](#purge_verbose)
* [`port`](#port)

##### <a name="vardir"></a>`vardir`

Data type: `Stdlib::AbsolutePath`

The directory where reports should be stored.

Default value: `$pupmod::master::vardir`

##### <a name="purge"></a>`purge`

Data type: `Boolean`

Whether or not to purge old reports from the system.

Default value: ``true``

##### <a name="purge_keep_days"></a>`purge_keep_days`

Data type: `Integer`

The number of days of reports to keep around on the system.

Default value: `7`

##### <a name="purge_verbose"></a>`purge_verbose`

Data type: `Optional[Boolean]`

DEPRECATED

* See the systemd tmpfiles logs for details

Default value: ``undef``

##### <a name="port"></a>`port`

Data type: `Optional[Simplib::Port]`

DEPRECATED

Default value: ``undef``

### <a name="pupmodmasterservice"></a>`pupmod::master::service`

Split out the 'service' for cleaner dependency ordering

#### Parameters

The following parameters are available in the `pupmod::master::service` class:

* [`service_name`](#service_name)

##### <a name="service_name"></a>`service_name`

Data type: `String[1]`

Name of the puppetserver service

Default value: `pupmod::server_distribution()`

### <a name="pupmodmastersimp_auth"></a>`pupmod::master::simp_auth`

Add SIMP-specific entries to PuppetServer's auth.conf

For documentation about *_allow and *_deny, see the puppetserver docs

* **See also**
  * https://puppet.com/docs/puppetserver/2.7/config_file_auth.html#rules

#### Parameters

The following parameters are available in the `pupmod::master::simp_auth` class:

* [`auth_conf_path`](#auth_conf_path)
* [`pki_cacerts_all`](#pki_cacerts_all)
* [`pki_mcollective_all`](#pki_mcollective_all)
* [`pki_cacerts_all`](#pki_cacerts_all)
* [`pki_cacerts_all_rule`](#pki_cacerts_all_rule)
* [`pki_cacerts_all_allow`](#pki_cacerts_all_allow)
* [`pki_cacerts_all_deny`](#pki_cacerts_all_deny)
* [`keydist_from_host`](#keydist_from_host)
* [`keydist_from_host_rule`](#keydist_from_host_rule)
* [`keydist_from_host_allow`](#keydist_from_host_allow)
* [`keydist_from_host_deny`](#keydist_from_host_deny)
* [`krb5_keytabs_from_host`](#krb5_keytabs_from_host)
* [`krb5_keytabs_from_host_rule`](#krb5_keytabs_from_host_rule)
* [`krb5_keytabs_from_host_allow`](#krb5_keytabs_from_host_allow)
* [`krb5_keytabs_from_host_deny`](#krb5_keytabs_from_host_deny)

##### <a name="auth_conf_path"></a>`auth_conf_path`

Data type: `Stdlib::AbsolutePath`

The location to the puppet master's auth.conf

Default value: `'/etc/puppetlabs/puppetserver/conf.d/auth.conf'`

##### <a name="pki_cacerts_all"></a>`pki_cacerts_all`

Data type: `Boolean`

Allow access to the cacerts from the `pki_files` module from all hosts

Default value: ``true``

##### <a name="pki_mcollective_all"></a>`pki_mcollective_all`

Data type: `Boolean`

Allow access to the mcollective PKI from the `pki_files` module from all
hosts

Default value: ``true``

##### <a name="pki_cacerts_all"></a>`pki_cacerts_all`

If enabled, allow access to the cacerts from the `pki_files` module from all hosts

Default value: ``true``

##### <a name="pki_cacerts_all_rule"></a>`pki_cacerts_all_rule`

Data type: `NotUndef`

The regex rule to match requests against. The provided rule matched requests
coming from the `files/keydist/cacerts` directory from the pki_files module

Default value: `'^/puppet/v3/file_(metadata|content)/modules/pki_files/keydist/cacerts'`

##### <a name="pki_cacerts_all_allow"></a>`pki_cacerts_all_allow`

Data type: `NotUndef`



Default value: `'*'`

##### <a name="pki_cacerts_all_deny"></a>`pki_cacerts_all_deny`

Data type: `Any`



Default value: ``undef``

##### <a name="keydist_from_host"></a>`keydist_from_host`

Data type: `Boolean`

If enabled, allow access to each host's own certs from the `pki_files` module

Default value: ``true``

##### <a name="keydist_from_host_rule"></a>`keydist_from_host_rule`

Data type: `NotUndef`

The regex rule to match requests against. The provided rule matched requests
coming from the `files/keydist` directory from the pki_files module

Default value: `'^/puppet/v3/file_(metadata|content)/modules/pki_files/keydist/([^/]+)'`

##### <a name="keydist_from_host_allow"></a>`keydist_from_host_allow`

Data type: `NotUndef`

Rules that the puppetserver should allow
@see https://puppet.com/docs/puppetserver/2.7/config_file_auth.html#rules

Default value: `'$2'`

##### <a name="keydist_from_host_deny"></a>`keydist_from_host_deny`

Data type: `Any`

Rules that the puppetserver should deny
@see https://puppet.com/docs/puppetserver/2.7/config_file_auth.html#rules

Default value: ``undef``

##### <a name="krb5_keytabs_from_host"></a>`krb5_keytabs_from_host`

Data type: `Boolean`

If enabled, allow access to each host's own kerberos keytabs from the `pki_files` module

Default value: ``true``

##### <a name="krb5_keytabs_from_host_rule"></a>`krb5_keytabs_from_host_rule`

Data type: `NotUndef`

The regex rule to match requests against. The provided rule matched requests
coming from the `files/keytabs` directory from the krb5_files module

Default value: `'^/puppet/v3/file_(metadata|content)/modules/krb5_files/keytabs/([^/]+)'`

##### <a name="krb5_keytabs_from_host_allow"></a>`krb5_keytabs_from_host_allow`

Data type: `NotUndef`

Rules that the puppetserver should allow
@see https://puppet.com/docs/puppetserver/2.7/config_file_auth.html#rules

Default value: `'$2'`

##### <a name="krb5_keytabs_from_host_deny"></a>`krb5_keytabs_from_host_deny`

Data type: `Any`

Rules that the puppetserver should deny
@see https://puppet.com/docs/puppetserver/2.7/config_file_auth.html#rules

Default value: ``undef``

### <a name="pupmodmastersysconfig"></a>`pupmod::master::sysconfig`

This class provides the sysconfig settings for the ``puppetserver`` daemon.

to use. To use the default enter 'default'. (Does not affect PE.)

* **See also**
  * https://puppet.com/docs/puppetserver/5.0/configuration.html#enabling-jruby-9k:

#### Parameters

The following parameters are available in the `pupmod::master::sysconfig` class:

* [`install_dir`](#install_dir)
* [`config`](#config)
* [`bootstrap_config`](#bootstrap_config)
* [`java_bin`](#java_bin)
* [`java_start_memory`](#java_start_memory)
* [`java_max_memory`](#java_max_memory)
* [`jruby_jar`](#jruby_jar)
* [`java_temp_dir`](#java_temp_dir)
* [`extra_java_args`](#extra_java_args)
* [`use_code_cache_flushing`](#use_code_cache_flushing)
* [`reserved_code_cache`](#reserved_code_cache)
* [`service_stop_retries`](#service_stop_retries)
* [`start_timeout`](#start_timeout)
* [`server_distribution`](#server_distribution)
* [`user`](#user)
* [`group`](#group)
* [`mock`](#mock)

##### <a name="install_dir"></a>`install_dir`

Data type: `Stdlib::AbsolutePath`

The installation directory for the ``puppetserver``.

##### <a name="config"></a>`config`

Data type: `Stdlib::AbsolutePath`

The configuration directory for the ``puppetserver``.

##### <a name="bootstrap_config"></a>`bootstrap_config`

Data type: `Array[Stdlib::AbsolutePath]`

The bootstrap configuration directory for the ``puppetserver``.

##### <a name="java_bin"></a>`java_bin`

Data type: `Stdlib::AbsolutePath`

The path to the java executable that the Puppet server should use on the
system.

Default value: `'/usr/bin/java'`

##### <a name="java_start_memory"></a>`java_start_memory`

Data type: `Optional[Pupmod::Memory]`

The amount of memory to allocate on service startup.

Default value: ``undef``

##### <a name="java_max_memory"></a>`java_max_memory`

Data type: `Optional[Pupmod::Memory]`

The maximum amount of memory to allocate within the system.

Default value: ``undef``

##### <a name="jruby_jar"></a>`jruby_jar`

Data type: `String`

The name of the jar file located in /opt/puppetlabs/apps/puppetserver

Default value: `'jruby-9k.jar'`

##### <a name="java_temp_dir"></a>`java_temp_dir`

Data type: `Optional[Stdlib::AbsolutePath]`

The temporary directory to be used for periodic executables.

* This should not be ``/tmp``, ``/var/tmp``, or ``/dev/shm`` on SIMP
  systems due to the default disabling of exec on those spaces.
* Preceeding directories will not be created.

Default value: ``undef``

##### <a name="extra_java_args"></a>`extra_java_args`

Data type: `Optional[Array[String]]`

An ``Array`` that will be joined and appended to the Java argument list.

* The sanity and syntax of this list will not be checked.

Default value: ``undef``

##### <a name="use_code_cache_flushing"></a>`use_code_cache_flushing`

Data type: `Boolean`

Enable code cache flushing to alleviate memory strain on the server

Default value: ``true``

##### <a name="reserved_code_cache"></a>`reserved_code_cache`

Data type: `Integer[0]`

An ``Integer`` of the MB to be used for JRuby options of ReservedCodeCache

* By default, this will auto-populate based on function

Default value: `pupmod::reserved_code_cache()`

##### <a name="service_stop_retries"></a>`service_stop_retries`

Data type: `Integer`

The number of times to attempt to stop the puppetserver process before
failing.

Default value: `60`

##### <a name="start_timeout"></a>`start_timeout`

Data type: `Integer`

The number of seconds after which the service will be determined to have
failed to start.

Default value: `120`

##### <a name="server_distribution"></a>`server_distribution`

Data type: `Simplib::ServerDistribution`

The Puppet distribution that is being managed.

Default value: `pupmod::server_distribution()`

##### <a name="user"></a>`user`

Data type: `String`

The ``user`` that the ``puppetserver`` service will run as.

Default value: `pick($facts.dig('puppet_settings','server','user'),$facts.dig('puppet_settings','master','user'))`

##### <a name="group"></a>`group`

Data type: `String`

The ``group`` that the ``puppetserver`` service will run as.

Default value: `pick($facts.dig('puppet_settings','server','group'),$facts.dig('puppet_settings','master','group'))`

##### <a name="mock"></a>`mock`

Data type: `Boolean`

Do not apply this class, only mock it up

Default value: ``false``

## Defined types

### <a name="pupmodconf"></a>`pupmod::conf`

This is a simple define to call the Puppet INIFile class for the passed
parameters on the puppet.conf file.

The main purpose is to easily allow for a service trigger.

#### Parameters

The following parameters are available in the `pupmod::conf` defined type:

* [`name`](#name)
* [`setting`](#setting)
* [`value`](#value)
* [`confdir`](#confdir)
* [`section`](#section)
* [`ensure`](#ensure)

##### <a name="name"></a>`name`

A globally unique name for this resource. Will be prefixed with $modname

##### <a name="setting"></a>`setting`

Data type: `String`

The setting in the section to set

##### <a name="value"></a>`value`

Data type: `Scalar`

The value of the setting to be set.

##### <a name="confdir"></a>`confdir`

Data type: `String`

The configuration directory holding the 'puppet.conf' file.

##### <a name="section"></a>`section`

Data type: `String`

The Section of the puppet.conf to set.

* If ``$setting`` is trying to be set to ``environment``, then this will be
  forced to ``agent`` to work around various puppet command bugs.

@see https://simp-project.atlassian.net/browse/SIMP-6820

Default value: `$setting`

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Determines whether the specified setting should exist.

Default value: `'present'`

### <a name="pupmodmasterautosign"></a>`pupmod::master::autosign`

Add an autosign entry to the puppet autosign file.

Ideally, autosign will not be used in your environment. However, should you
happen to need it

#### Parameters

The following parameters are available in the `pupmod::master::autosign` defined type:

* [`name`](#name)
* [`entry`](#entry)

##### <a name="name"></a>`name`

A useful comment for the entry being signed

##### <a name="entry"></a>`entry`

Data type: `Optional[Pattern['^(\*\.)?\S+$']]`

The autosign entry to add to the file if ``$name`` is used as a unique comment

Default value: ``undef``

### <a name="pupmodmasterfileserver_entry"></a>`pupmod::master::fileserver_entry`

Manage entries in the /etc/puppet/fileserver.conf file.

#### Parameters

The following parameters are available in the `pupmod::master::fileserver_entry` defined type:

* [`name`](#name)
* [`allow`](#allow)
* [`path`](#path)

##### <a name="name"></a>`name`

The name of the [] segment.

##### <a name="allow"></a>`allow`

Data type: `Variant[Array[Simplib::Host],Simplib::Host]`

An array of entries to add to the allow statement.

##### <a name="path"></a>`path`

Data type: `Stdlib::AbsolutePath`

The filesystem path to which this segment should point.

### <a name="pupmodpass_two"></a>`pupmod::pass_two`

Puppet 4+ installations.

* **See also**
  * comment
    * at manifests/init.pp:244

#### Parameters

The following parameters are available in the `pupmod::pass_two` defined type:

* [`namevar`](#namevar)
* [`server_distribution`](#server_distribution)
* [`confdir`](#confdir)
* [`firewall`](#firewall)
* [`pe_classlist`](#pe_classlist)
* [`pupmod_server`](#pupmod_server)
* [`pupmod_ca_server`](#pupmod_ca_server)
* [`pupmod_ca_port`](#pupmod_ca_port)
* [`pupmod_report`](#pupmod_report)
* [`pupmod_masterport`](#pupmod_masterport)

##### <a name="namevar"></a>`namevar`

Data type: `String`



Default value: `$name`

##### <a name="server_distribution"></a>`server_distribution`

Data type: `Simplib::ServerDistribution`



Default value: `pupmod::server_distribution()`

##### <a name="confdir"></a>`confdir`

Data type: `Stdlib::AbsolutePath`



Default value: `'/etc/puppetlabs/puppet'`

##### <a name="firewall"></a>`firewall`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="pe_classlist"></a>`pe_classlist`

Data type: `Hash`



Default value: `lookup('pupmod::pe_classlist')`

##### <a name="pupmod_server"></a>`pupmod_server`

Data type: `Variant[Simplib::Host, Array[Simplib::Host]]`



Default value: `'1.2.3.4'`

##### <a name="pupmod_ca_server"></a>`pupmod_ca_server`

Data type: `Variant[Simplib::Host,Enum['$server']]`



Default value: `'$server'`

##### <a name="pupmod_ca_port"></a>`pupmod_ca_port`

Data type: `Simplib::Port`



Default value: `8141`

##### <a name="pupmod_report"></a>`pupmod_report`

Data type: `Boolean`



Default value: ``false``

##### <a name="pupmod_masterport"></a>`pupmod_masterport`

Data type: `Simplib::Port`



Default value: `8140`

## Functions

### <a name="pupmodjava_max_memory"></a>`pupmod::java_max_memory`

Type: Puppet Language

Provides a reasonable calculation for the reserved code cache value for JRuby
for a system

#### `pupmod::java_max_memory(Integer[1] $max_active_instances = 1)`

Provides a reasonable calculation for the reserved code cache value for JRuby
for a system

Returns: `Pupmod::Memory` The maximum number of JRuby instances that should be active on the ``puppetserver``

##### `max_active_instances`

Data type: `Integer[1]`



### <a name="pupmodmax_active_instances"></a>`pupmod::max_active_instances`

Type: Puppet Language

Provides a reasonable calculation for the maximum number of active instances
for a system

Parameters are not to be used but are present as an assist to testing

#### `pupmod::max_active_instances(Enum['monolithic', 'primary', 'compile'] $server_type = 'monolithic')`

Provides a reasonable calculation for the maximum number of active instances
for a system

Parameters are not to be used but are present as an assist to testing

Returns: `Integer` The maximum number of JRuby instances that should be active on the ``puppetserver``

##### `server_type`

Data type: `Enum['monolithic', 'primary', 'compile']`



### <a name="pupmodreserved_code_cache"></a>`pupmod::reserved_code_cache`

Type: Puppet Language

Provides a reasonable calculation for the reserved code cache value for JRuby
for a system

#### `pupmod::reserved_code_cache()`

Provides a reasonable calculation for the reserved code cache value for JRuby
for a system

Returns: `Integer` The maximum number of JRuby instances that should be active on the ``puppetserver``

### <a name="pupmodserver_distribution"></a>`pupmod::server_distribution`

Type: Puppet Language

Figure out if we're running PC1 or PE puppet

#### `pupmod::server_distribution(Boolean $lookup_from_pupmod = true)`

Figure out if we're running PC1 or PE puppet

Returns: `String` 'PE' or 'PC1' as applicable

##### `lookup_from_pupmod`

Data type: `Boolean`

Attempt to look up the value from `$pupmod::server_distribution`

### <a name="pupmodserver_version"></a>`pupmod::server_version`

Type: Puppet Language

Authoritatively determine the puppet server version and return `0.0.0` if one
could not be determined.

#### `pupmod::server_version()`

Authoritatively determine the puppet server version and return `0.0.0` if one
could not be determined.

Returns: `String` The puppet server version

## Data types

### <a name="pupmodcattl"></a>`Pupmod::CaTTL`

Matches valid Puppet CA TTL configuration

Alias of

```puppet
Variant[Integer, Pattern[/^\d+[smhdy]$/]]
```

### <a name="pupmodloglevel"></a>`Pupmod::LogLevel`

puppetserver log levels

Alias of

```puppet
Enum['TRACE', 'DEBUG', 'INFO', 'WARN', 'ERROR', 'OFF']
```

### <a name="pupmodmastersslciphersuites"></a>`Pupmod::Master::SSLCiphersuites`

Valid SSL Cipher Suites for the Puppet Master Webserver

Alias of

```puppet
Enum['TLS_RSA_WITH_AES_256_GCM_SHA384', 'TLS_RSA_WITH_AES_256_CBC_SHA256', 'TLS_RSA_WITH_AES_256_CBC_SHA', 'TLS_RSA_WITH_AES_128_GCM_SHA256', 'TLS_RSA_WITH_AES_128_CBC_SHA256', 'TLS_RSA_WITH_AES_128_CBC_SHA', 'TLS_ECDH_RSA_WITH_AES_256_GCM_SHA384', 'TLS_ECDH_RSA_WITH_AES_256_CBC_SHA384', 'TLS_ECDH_RSA_WITH_AES_256_CBC_SHA', 'TLS_ECDH_RSA_WITH_AES_128_GCM_SHA256', 'TLS_ECDH_RSA_WITH_AES_128_CBC_SHA256', 'TLS_ECDH_RSA_WITH_AES_128_CBC_SHA', 'TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384', 'TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA384', 'TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA', 'TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256', 'TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA256', 'TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA', 'TLS_ECDHE_ECDSA_WITH_AES_256_GCM_SHA384', 'TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA384', 'TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA', 'TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256', 'TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256', 'TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA', 'TLS_ECDH_ECDSA_WITH_AES_256_GCM_SHA384', 'TLS_ECDH_ECDSA_WITH_AES_256_CBC_SHA384', 'TLS_ECDH_ECDSA_WITH_AES_256_CBC_SHA', 'TLS_ECDH_ECDSA_WITH_AES_128_GCM_SHA256', 'TLS_ECDH_ECDSA_WITH_AES_128_CBC_SHA256', 'TLS_ECDH_ECDSA_WITH_AES_128_CBC_SHA', 'TLS_DHE_RSA_WITH_AES_256_GCM_SHA384', 'TLS_DHE_RSA_WITH_AES_256_CBC_SHA256', 'TLS_DHE_RSA_WITH_AES_256_CBC_SHA', 'TLS_DHE_RSA_WITH_AES_128_GCM_SHA256', 'TLS_DHE_RSA_WITH_AES_128_CBC_SHA256', 'TLS_DHE_RSA_WITH_AES_128_CBC_SHA', 'TLS_DHE_DSS_WITH_AES_256_GCM_SHA384', 'TLS_DHE_DSS_WITH_AES_256_CBC_SHA256', 'TLS_DHE_DSS_WITH_AES_256_CBC_SHA', 'TLS_DHE_DSS_WITH_AES_128_GCM_SHA256', 'TLS_DHE_DSS_WITH_AES_128_CBC_SHA256', 'TLS_DHE_DSS_WITH_AES_128_CBC_SHA', 'TLS_EMPTY_RENEGOTIATION_INFO_SCSV']
```

### <a name="pupmodmastersslprotocols"></a>`Pupmod::Master::SSLProtocols`

Valid SSL Protocols for the Puppet Master Webserver

Alias of

```puppet
Enum['TLSv1', 'TLSv1.1', 'TLSv1.2']
```

### <a name="pupmodmemory"></a>`Pupmod::Memory`

Matches valid puppetserver JAVA memory parameters

Alias of

```puppet
Pattern['^\d+(g|k|m|%)$']
```

### <a name="pupmodprofilingmode"></a>`Pupmod::ProfilingMode`

puppetserver profiling modes

Alias of

```puppet
Enum['off', 'api', 'flat', 'graph', 'html', 'json', 'service']
```

